Learn R Programming

safeframe (version 1.0.0)

has_tag: A selector function to use in tidyverse functions

Description

A selector function to use in tidyverse functions

Usage

has_tag(tags)

Value

A numeric vector containing the position of the columns with the requested tags

Arguments

tags

A character vector of tags you want to operate on

Examples

Run this code
## create safeframe
x <- make_safeframe(cars,
  mph = "speed",
  distance = "dist"
)
head(x)

if (require(dplyr) && require(magrittr)) {
  x %>%
    select(has_tag(c("mph", "distance"))) %>%
    head()
}

Run the code above in your browser using DataLab